@@ -13,11 +13,5 @@
 #' cache will be in a temporary directory that does not persist between
 #' sessions.
 #'
-#' @importFrom rlang expr
 #' @keywords internal
 "_PACKAGE"
-
-## usethis namespace: start
-#' @importFrom rlang %||%
-## usethis namespace: end
-NULL
